// Scourge currently just uses simple AABB (Axis-Aligned Bounding Box) collision, which is accurate,
// fast and simple to understand. Read the document "Scourge Collision.txt" in the docs folder to
// get an idea of how this is implemented

#ifndef SCOURGE_COLLISION_H
#define SCOURGE_COLLISION_H

#include "scourge_debug.h"
// First define a structure that contains the bounding box data

typedef struct
{
    float x1, x2; // x1 == left, x2 == right
    float y1, y2; // y1 == top, y2 == bottom
    float z1, z2; // z1 == front, z2 == back
}scBBox;

class SC_BOUNDS // SC_BOUNDS handles collision detection
{
    public:
    scBBox box; // Bounding box data
    scBBox relBox; // Relative bounding box data. Must be set with SetPos before testing for collision


    SC_BOUNDS(float x1=0, float x2=1, float y1=0, float y2=-1, float z1=0, float z2=1); // Calls Update with these arguments
    ~SC_BOUNDS(){} // Blank destructor again >_>

    void Update(float x1, float x2, float y1, float y2, float z1, float z2); // For updating the bounding box
    void SetPos(float x, float y, float z);

    // This function tests for a collision between this class and another
    bool Collide(SC_BOUNDS *otherBox);

    // This one checks for a coordinate that is colliding

    bool PointCollide(float x, float y, float z);
};

#endif
