// Contains some useful 'primitives' such as planes, cubes, etc
// These are all designed to be axis-aligned shapes, with no rotation.

#ifndef SCOURGE_PRIMITIVES_H
#define SCOURGE_PRIMITIVES_H

#include "scourge_texture.h"
#include "scourge_collision.h"

class SC_PRIMITIVE
{
    public:
    float x, y, z;
    bool Textured;
    bool Lit;
    bool Blended;
    float color[4]; // R, G, B, A (Alpha, only accounted for is Blending is enabled

    SC_TEXTURE* texture; // Only used if Textured is enabled, but it is initialized anyway to the default texture
    SC_BOUNDS*  bounding; // Bounding box used for collision

    SC_PRIMITIVE(float xx, float yy, float zz,SC_TEXTURE* defaultTexture); // defaultTexture must be supplied from the game/app using the library
    SC_PRIMITIVE();

    GLuint GetTexture(); // Returns the texture ID
    virtual ~SC_PRIMITIVE();

    virtual void Draw(); // Virtual draw function

    void EventDraw()
    {
        //OnDraw();
    }

    void EventUpdate(int delta)
    {
        //OnUpdate(delta);
    }

    void EventDestroy();
    void EventCollision();

    //virtual void OnDraw();
    //virtual void OnUpdate(int delta);
    //virtual void OnDestroy();
    //virtual void OnCollision();
};

class SC_CUBE:public SC_PRIMITIVE
{
    // A simple cube, textured and with Normal coordinates
    public:
    SC_CUBE(float xx, float yy, float zz, SC_TEXTURE* topTex, SC_TEXTURE* bottomTex, SC_TEXTURE* sideTex);
    SC_CUBE();
    virtual ~SC_CUBE();

    GLuint displist; // Precompiled display list :D

    SC_TEXTURE *top, *bottom, *sides;

    virtual void Draw();
    virtual void SetList(GLuint list);
    virtual GLuint MakeList();
    virtual void DrawS(); // Draws in list mode

    //virtual void Update(); // Updates the bounding box
    //virtual bool TestCollision(SC_BOUNDS* ex); // Tests for a collision with bounding box ex

    //virtual void OnDraw();
    //virtual void OnUpdate(int delta);
    //virtual void OnDestroy();
    //virtual void OnCollision();
};

#endif
